//
// UIViewController+Utilities.h
//
// Created by Mel Sampat on 5/11/12.
// Copyright (c) 2012 Mel Sampat.
//
// MIT LICENSE:

// Permission is hereby granted, free of charge, to any person obtaining a 
// copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
// THE SOFTWARE.

typedef enum {
    NavBarButtonsDoneAndCancel,
    NavBarButtonsDoneOnly,
    NavBarButtonsCancelOnly,
} NavBarButtonsType;

@interface UIViewController (Utilities)

// Add standard Done and Cancel buttons to a NavigationBar.
// Why? A typical app can contain many modal views, each of which may need
// the Done and/or Cancel buttons in its NavigationBar. This method makes 
// creating those buttons easier by reusing code. Although simple, this trick
// allows me to eliminate dozens of lines of duplicate code from every app.

// To use this method, simply 
// call it in your UIViewController's viewDidLoad as shown below:
//
//     - (void)viewDidLoad {
//        [super viewDidLoad];
//        [self addNavBarButtonsOfType: NavBarButtonsDoneAndCancel];
//     }
//
// Important: You have to handle the doneButtonTapped: and/or cancelButtonTapped: actions.
// 
//     - (void)doneButtonTapped:(id)sender {
//        NSLog(@"Done button tapped!");
//     }
//
- (void)addNavBarButtonsOfType:(NavBarButtonsType)type;

@end
